@@ -58,6 +58,9 @@ class Command(BaseCommand):
         js_paths = finders.find("js/", True)
         # Remove paths inside of collection dir
         js_paths = [x for x in js_paths if not x.startswith(STATIC_ROOT)]
+        # Reverse list so that overrides function as expected. Static file from
+        # first app mentioned in INSTALLED_APPS has preference.
+        js_path.reverse()
 
         transpile_path = os.path.join(PROJECT_PATH, "static-transpile")
 
